@@ -15,6 +15,7 @@ const (
 	OpenShiftConsoleConfigMapName       = "console-config"
 	OpenShiftConsolePublicConfigMapName = "console-public"
 	ServiceCAConfigMapName              = "service-ca"
+	DefaultIngressCertConfigMapName     = "default-ingress-cert"
 	OpenShiftConsoleDeploymentName      = OpenShiftConsoleName
 	OpenShiftConsoleServiceName         = OpenShiftConsoleName
 	OpenShiftConsoleRouteName           = OpenShiftConsoleName
@@ -22,6 +23,7 @@ const (
 	OAuthClientName                     = OpenShiftConsoleName
 	OpenShiftConfigManagedNamespace     = "openshift-config-managed"
 	OpenShiftConfigNamespace            = "openshift-config"
+	OpenShiftMonitoringConfigMapName    = "monitoring-shared-config"
 	OpenShiftCustomLogoConfigMapName    = "custom-logo"
 	TrustedCAConfigMapName              = "trusted-ca-bundle"
 	TrustedCABundleKey                  = "ca-bundle.crt"
